# OrderLineItemBillingRule

The rule for billing of the Order Line Item (OLI).  You can update this field for a sales or return OLI only when it is in the `Executing` state (when the `itemState` field is set as `Executing`). 

## Enum

* `TRIGGERWITHOUTFULFILLMENT` (value: `'TriggerWithoutFulfillment'`)

* `TRIGGERASFULFILLMENTOCCURS` (value: `'TriggerAsFulfillmentOccurs'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


